@@ -7,9 +7,15 @@
 # Invenio is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
 
-pydocstyle invenio_assets tests docs && \
-isort -rc -c -df && \
-check-manifest --ignore ".travis-*" && \
-sphinx-build -qnNW docs docs/_build/html && \
-python setup.py test && \
+# Quit on errors
+set -o errexit
+
+# Quit on unbound symbols
+set -o nounset
+
+pydocstyle invenio_assets tests docs
+isort invenio_assets tests --check-only --diff
+check-manifest --ignore ".*-requirements.txt"
+sphinx-build -qnNW docs docs/_build/html
+python setup.py test
 sphinx-build -qnNW -b doctest docs docs/_build/doctest
